uorb: use single byte for internal types in o_fields metadata

Reduces flash usage by ~9KB.
This commit is contained in:
Beat Küng
2021-10-20 08:10:05 +02:00
parent 9aaf6e3f3e
commit 4c73ac3805
8 changed files with 131 additions and 36 deletions
+2
View File
@@ -277,6 +277,8 @@ private:
void setUserParams(const char *filename);
std::string parseOrbFields(const std::string &fields);
static char *_replay_file;
};